#include <avr/io.h>
#include <avr/interrupt.h>

#define F_CPU 16000000L
#include <util/delay.h>

#define IN 1
#define ST 2
#define DR 3
#define NE 4

void to_right(){
	//oprim motorul stang si il pornim pe dreptul, lasam comanda sa se execute
	PORTB &= ~(1 << PB3);	
	PORTB |= (1 << PB1);
	_delay_ms(15);
}

void to_left(){
	//oprim motorul drept si il pornim pe stangul, lasam comanda sa se execute
	PORTB &= ~(1 << PB1); 
	PORTB |= (1 << PB3);
	_delay_ms(15);
}

void init_robo(){
	//PB output prin care controlez motoarele
	DDRB = 0xFF;
	PORTB = 0;
	
	//porturi de citire de la sensori
	DDRA = 0;
	PORTA = 0xFF;
}

int main(void)
{
	init_robo();

	int val = 0, i, last = ST;
	
	while (1) {

		//oprim motoarele
		PORTB &= ~(1 << PB1);
		PORTB &= ~(1 << PB3);
		_delay_ms(10);

		val = 0;
		
		for (i = 0; i < 8; i++) {
			if (PINA & (1 << i)) {
				val += 1;
			}
		}
		
		if (val == 0 || val == 8) {
			if(last == DR){
				to_right();
				continue;
			} else {
				to_left();
				continue;
			}
		}
		
		val = 0;
		//senzori dreapta
		for (i = 0; i < 4; i++) {
			if (PINA & (1 << i)) {
				val -= 1;
			}
		}
		
		//senzori stanga
		for (i = 4; i < 8; i++) {
			if (PINA & (1 << i)) {
				val += 1;
			}
		}
		
		if (val > 0) { //mergem la dreapta
			to_right();
			last = DR;
			continue;
		}
		
		if (val < 0) { //mergem la stanga
			to_left();
			last = ST;
			continue;
		}
		
		//sunt echilibrati senzirii, executam ultima miscaree
		if(last == DR){
			to_right();
			continue;
		}
		
		to_left();
		continue;
	}

	return 0;
}